@@ -55,7 +55,6 @@ macro_rules! pod {
 #[derive(Clone, Copy)]
 struct DataInfo {
     size: usize,
-    align: usize,
 }
 
 // 2 purposes: Prevent monomorphization as much as possible, and allow for using
@@ -112,10 +111,12 @@ where
     const ALIGN: usize = const_max(core::mem::align_of::<T>(), 8);
 
     pub fn with_allocator(allocator: A) -> Self {
-        let info = DataInfo {
-            size: Self::SIZE,
-            align: Self::ALIGN,
-        };
+        assert!(
+            Self::ALIGN <= 8,
+            "Pod only supports an alignment of up to 8"
+        );
+
+        let info = DataInfo { size: Self::SIZE };
 
         return Self {
             raw: RawPod::new(info),
@@ -221,10 +222,24 @@ where
         return self.raw.length;
     }
 
+    pub fn resize(&mut self, size: usize, fill: T) {
+        if size > self.raw.capacity {
+            self.raw.realloc(&self.allocator, size);
+        }
+
+        if size > self.raw.length {
+            let ptr = self.raw.ptr(self.raw.length) as *mut T;
+            let data = unsafe { core::slice::from_raw_parts_mut(ptr, size - self.raw.length) };
+            data.fill(fill);
+        }
+
+        self.raw.length = size;
+    }
+
     #[cfg_attr(not(debug_assertions), inline(always))]
     pub unsafe fn set_len(&mut self, new_len: usize) {
         debug_assert!(
-            new_len < self.raw.capacity,
+            new_len <= self.raw.capacity,
             "set_len got value that was too large! capa={}, new_len={}",
             self.raw.capacity,
             new_len
@@ -242,6 +257,19 @@ where
         self.raw.length = new_len;
     }
 
+    pub fn extend_uninit(&mut self, extend: usize) -> (&[T], &mut [T]) {
+        self.raw.reserve_additional(&self.allocator, extend);
+
+        let old_len = self.raw.length;
+        self.raw.length += extend;
+
+        let ptr = self.raw.ptr(0) as *mut T;
+        let data = unsafe { core::slice::from_raw_parts_mut(ptr, self.raw.length) };
+        let (from, to) = data.split_at_mut(old_len);
+
+        return (&*from, to);
+    }
+
     #[inline(always)]
     pub fn reserve(&mut self, additional: usize) {
         self.raw.reserve_additional(&self.allocator, additional);
@@ -576,7 +604,7 @@ impl RawPod {
         alloc: &dyn Allocator,
         elem_capacity: usize,
     ) -> Result<(), &'static str> {
-        let (size, align) = (self.info.size, self.info.align);
+        let (size, align) = (self.info.size, 8);
         let get_info = move |mut data: NonNull<[u8]>| -> (NonNull<u8>, usize) {
             let data = unsafe { data.as_mut() };
             let capacity = data.len() / size;
